package org.bouncycastle.asn1.pkcs;

import java.io.*;
import java.util.*;

import org.bouncycastle.asn1.*;
import org.bouncycastle.asn1.x509.*;

/**
 * PKCS10
 *
 * <pre>
 * CertificationRequest ::= SEQUENCE {
 *   certificationRequestInfo  CertificationRequestInfo,
 *   signatureAlgorithm        AlgorithmIdentifier{{ SignatureAlgorithms }},
 *   signature                 BIT STRING
 * }
 * </pre>
 */
public class CertificationRequest
    implements DEREncodable
{
    DERConstructedSequence seq;

    protected CertificationRequestInfo reqInfo = null;
    protected AlgorithmIdentifier sigAlgId = null;
    protected DERBitString sigBits = null;

    protected CertificationRequest()
    {
    }

    public CertificationRequest(
        CertificationRequestInfo requestInfo,
        AlgorithmIdentifier     algorithm,
        DERBitString            signature)
    {
        this.reqInfo = requestInfo;
        this.sigAlgId = algorithm;
        this.sigBits = signature;
    }

    public CertificationRequest(
        DERConstructedSequence seq)
    {
        this.seq = seq;

        if ( seq.getObjectAt(0) instanceof CertificationRequestInfo )
        {
            reqInfo = (CertificationRequestInfo)seq.getObjectAt(0);
        }
        else
        {
            reqInfo = new CertificationRequestInfo((DERConstructedSequence)seq.getObjectAt(0));
        }

        if ( seq.getObjectAt(1) instanceof AlgorithmIdentifier )
        {
            sigAlgId = (AlgorithmIdentifier)seq.getObjectAt(1);
        }
        else
        {
            sigAlgId = new AlgorithmIdentifier((DERConstructedSequence)seq.getObjectAt(1));
        }

        sigBits = (DERBitString)seq.getObjectAt(2);
    }

    public CertificationRequestInfo getCertificationRequestInfo()
    {
        return reqInfo;
    }

    public AlgorithmIdentifier getSignatureAlgorithm()
    {
        return sigAlgId;
    }

    public DERBitString getSignature()
    {
        return sigBits;
    }

    public DERObject getDERObject()
    {
        // Construct the CertificateRequest
        DERConstructedSequence  seq = new DERConstructedSequence();

        seq.addObject(reqInfo);
        seq.addObject(sigAlgId);
        seq.addObject(sigBits);

        return seq;
    }
}
